@@ -27,11 +27,19 @@ def set_cookies(cookies):
         missing_cookies = [c for c in ['c_user', 'xs'] if c not in cookies]
         if missing_cookies:
             raise exceptions.InvalidCookies(f"Missing cookies with name(s): {missing_cookies}")
-        _scraper.session.cookies = cookies
+        _scraper.session.cookies.update(cookies)
+        if not _scraper.is_logged_in():
+            raise exceptions.InvalidCookies(f"Cookies are not valid")
 
 def set_proxy(proxy):
     _scraper.set_proxy(proxy)
 
+def set_user_agent(user_agent):
+    _scraper.set_user_agent(user_agent)
+
+def set_noscript(noscript):
+    _scraper.set_noscript(noscript)
+
 def get_profile(
     account: str,
     **kwargs,
@@ -118,7 +126,8 @@ def get_posts(
         kwargs['page_limit'] = kwargs.pop('pages')
 
     # TODO: Deprecate `extra_info` in favor of `options`
-    options['reactions'] = kwargs.pop('extra_info', False)
+    if "reactions" not in options:
+        options['reactions'] = kwargs.pop('extra_info', False)
     options['youtube_dl'] = kwargs.pop('youtube_dl', False)
 
     if credentials is not None:
@@ -136,6 +145,65 @@ def get_posts(
     raise ValueError('No account nor group')
 
 
+def get_photos(
+    account: str,
+    credentials: Optional[Credentials] = None,
+    **kwargs,
+) -> Iterator[Post]:
+    """Get photo posts from a Facebook page.
+
+    Args:
+        account (str): The account of the page.
+        credentials (Optional[Tuple[str, str]]): Tuple of email and password to login before scraping.
+        timeout (int): Timeout for requests.
+        page_limit (int): How many pages of posts to go through.
+            Use None to try to get all of them.
+        extra_info (bool): Set to True to try to get reactions.
+        youtube_dl (bool): Use Youtube-DL for video extraction.
+        cookies (Union[dict, CookieJar, str]): Cookie jar to use.
+            Can also be a filename to load the cookies from a file (Netscape format).
+
+    Yields:
+        dict: The post representation in a dictionary.
+    """
+    if account is None:
+        raise ValueError("You need to specify account")
+
+    _scraper.requests_kwargs['timeout'] = kwargs.pop('timeout', DEFAULT_REQUESTS_TIMEOUT)
+
+    cookies = kwargs.pop('cookies', None)
+
+    if cookies is not None and credentials is not None:
+        raise ValueError("Can't use cookies and credentials arguments at the same time")
+    set_cookies(cookies)
+
+    options: Union[Dict[str, Any], Set[str]] = kwargs.setdefault('options', {})
+    if isinstance(options, set):
+        warnings.warn("The options argument should be a dictionary.", stacklevel=2)
+        options = {k: True for k in options}
+    options.setdefault('account', account)
+
+    # TODO: Add a better throttling mechanism
+    if 'sleep' in kwargs:
+        warnings.warn(
+            "The sleep parameter has been removed, it won't have any effect.", stacklevel=2
+        )
+        kwargs.pop('sleep')
+
+    # TODO: Deprecate `pages` in favor of `page_limit` since it is less confusing
+    if 'pages' in kwargs:
+        kwargs['page_limit'] = kwargs.pop('pages')
+
+    # TODO: Deprecate `extra_info` in favor of `options`
+    options['reactions'] = kwargs.pop('extra_info', False)
+    options['youtube_dl'] = kwargs.pop('youtube_dl', False)
+
+    if credentials is not None:
+        _scraper.login(*credentials)
+
+    return _scraper.get_photos(account, **kwargs)
+
+
 def write_posts_to_csv(
     account: Optional[str] = None,
     group: Union[str, int, None] = None,
@@ -188,7 +256,11 @@ def write_posts_to_csv(
             except Exception:
                 logger.exception("Error writing post to disk")
 
-    keys = list_of_posts[0].keys()
+    keys = list(list_of_posts[0].keys())
+    for post in list_of_posts:
+        for key in post.keys():
+            if key not in keys:
+                keys.append(key)
 
     if filename is None:
         filename = str(account or group) + "_posts.csv"
