@@ -18,9 +18,10 @@ logger = logging.getLogger(__name__)
 
 
 def iter_pages(account: str, request_fn: RequestFunction, **kwargs) -> Iterator[Page]:
-    if kwargs.get("start_url"):
+    start_url = None
+    if "start_url" in kwargs:
         start_url = kwargs.pop("start_url")
-    else:
+    if not start_url:
         start_url = utils.urljoin(FB_MOBILE_BASE_URL, f'/{account}/posts/')
         try:
             request_fn(start_url)
